@@ -78,7 +78,7 @@ use std::{
 };
 
 /// `lock_state_t_t` type represents possible states for the sandbox lock.
-#[allow(non_camel_case_types)]
+#[expect(non_camel_case_types)]
 pub type lock_state_t = u8;
 
 /// The sandbox lock is off, allowing all sandbox commands.
@@ -127,7 +127,7 @@ impl fmt::Display for LockState {
 }
 
 /// `action_t` type represents possible sandboxing action values.
-#[allow(non_camel_case_types)]
+#[expect(non_camel_case_types)]
 pub type action_t = u8;
 
 /// Allow system call.
