@@ -32,7 +32,7 @@ use crate::{
 
 // Note, sysenter_exec is a ptrace(2) hook, not a seccomp hook!
 // The seccomp hooks are only used with trace/allow_unsafe_ptrace:1.
-#[allow(clippy::cognitive_complexity)]
+#[expect(clippy::cognitive_complexity)]
 pub(crate) fn sysenter_exec(
     pid: Pid,
     sandbox: &SandboxGuard,
@@ -44,7 +44,7 @@ pub(crate) fn sysenter_exec(
         unreachable!("BUG: Invalid system call information returned by kernel!");
     };
 
-    #[allow(clippy::cast_possible_truncation)]
+    #[expect(clippy::cast_possible_truncation)]
     let (syscall_name, arg, chk) = match data.ret_data as u16 {
         PTRACE_DATA_EXECVE => (
             "execve",
@@ -141,7 +141,7 @@ pub(crate) fn sysenter_exec(
     //    if the file is not executable.
     // 2. We set MUST_PATH in FsFlags, path.dir is always Some.
     // This uses AT_EXECVE_CHECK on Linux>=6.14.
-    #[allow(clippy::disallowed_methods)]
+    #[expect(clippy::disallowed_methods)]
     if !is_executable(path.dir.as_ref().unwrap()) {
         return Err(Errno::EACCES);
     }
@@ -180,7 +180,7 @@ pub(crate) fn sysenter_exec(
     // Trusted Path Execution.
     if caps.contains(Capability::CAP_TPE) {
         // MUST_PATH ensures path.dir is Some.
-        #[allow(clippy::disallowed_methods)]
+        #[expect(clippy::disallowed_methods)]
         let file = path.dir.as_ref().unwrap();
         let (action, msg) = sandbox.check_tpe(file, path.abs());
         if !matches!(action, Action::Allow | Action::Filter) {
@@ -229,13 +229,13 @@ pub(crate) fn sysenter_exec(
     };
 
     // Parse ELF as necessary for restrictions.
-    let deny_script = sandbox.flags.deny_script();
-    let restrict_32 = sandbox.flags.deny_elf32();
-    let restrict_dyn = sandbox.flags.deny_elf_dynamic();
-    let restrict_sta = sandbox.flags.deny_elf_static();
-    let restrict_ldd = !sandbox.flags.allow_unsafe_ldso();
-    let restrict_pie = !sandbox.flags.allow_unsafe_nopie();
-    let restrict_xs = !sandbox.flags.allow_unsafe_stack();
+    let deny_script = sandbox.flags.deny_exec_script();
+    let restrict_32 = sandbox.flags.deny_exec_elf32();
+    let restrict_dyn = sandbox.flags.deny_exec_elf_dynamic();
+    let restrict_sta = sandbox.flags.deny_exec_elf_static();
+    let restrict_ldd = !sandbox.flags.allow_unsafe_exec_ldso();
+    let restrict_pie = !sandbox.flags.allow_unsafe_exec_nopie();
+    let restrict_xs = !sandbox.flags.allow_unsafe_exec_stack();
 
     let check_linking = restrict_ldd || restrict_dyn || restrict_sta || restrict_pie || restrict_xs;
 
@@ -271,9 +271,10 @@ pub(crate) fn sysenter_exec(
     let is_script = exe == ExecutableFile::Script;
     if is_script && deny_script {
         if !sandbox.filter_path(Capability::CAP_EXEC, path.abs()) {
-            error!("ctx": "deny_script",
+            error!("ctx": "deny_exec_script",
                 "msg": "script execution denied",
                 "pid": pid.as_raw(), "path": path.abs(),
+                "tip": "configure `trace/deny_exec_script:0'",
                 "exe": format!("{exe}"));
         }
         return Err(Errno::EACCES);
@@ -293,7 +294,7 @@ pub(crate) fn sysenter_exec(
             error!("ctx": "check_elf",
                 "msg": "ld.so(8) exec-indirection prevented",
                 "pid": pid.as_raw(), "path": path.abs(),
-                "tip": "configure `trace/allow_unsafe_ldso:1'",
+                "tip": "configure `trace/allow_unsafe_exec_ldso:1'",
                 "exe": format!("{exe}"));
         }
         return Err(Errno::EACCES);
@@ -303,7 +304,7 @@ pub(crate) fn sysenter_exec(
         if !sandbox.filter_path(Capability::CAP_EXEC, path.abs()) {
             error!("ctx": "check_elf", "msg": "ELF is not Position Independent Executable (PIE)",
                 "pid": pid.as_raw(), "path": path.abs(),
-                "tip": "configure `trace/allow_unsafe_nopie:1'",
+                "tip": "configure `trace/allow_unsafe_exec_nopie:1'",
                 "exe": format!("{exe}"));
         }
         return Err(Errno::EACCES);
@@ -313,7 +314,7 @@ pub(crate) fn sysenter_exec(
         if !sandbox.filter_path(Capability::CAP_EXEC, path.abs()) {
             error!("ctx": "check_elf", "msg": "ELF has executable stack",
                 "pid": pid.as_raw(), "path": path.abs(),
-                "tip": "configure `trace/allow_unsafe_stack:1'",
+                "tip": "configure `trace/allow_unsafe_exec_stack:1'",
                 "exe": format!("{exe}"));
         }
         return Err(Errno::EACCES);
@@ -332,7 +333,7 @@ pub(crate) fn sysenter_exec(
         if !sandbox.filter_path(Capability::CAP_EXEC, path.abs()) {
             error!("ctx": "check_elf", "msg": "32-bit ELF execution prevented",
                 "pid": pid.as_raw(), "path": path.abs(),
-                "tip": "configure `trace/deny_elf32:0'",
+                "tip": "configure `trace/deny_exec_elf32:0'",
                 "exe": format!("{exe}"));
         }
         return Err(Errno::EACCES);
@@ -351,7 +352,7 @@ pub(crate) fn sysenter_exec(
         if !sandbox.filter_path(Capability::CAP_EXEC, path.abs()) {
             error!("ctx": "check_elf", "msg": "dynamic linked ELF execution prevented",
                 "pid": pid.as_raw(), "path": path.abs(),
-                "tip": "configure `trace/deny_elf_dynamic:0'",
+                "tip": "configure `trace/deny_exec_elf_dynamic:0'",
                 "exe": format!("{exe}"));
         }
         return Err(Errno::EACCES);
@@ -370,7 +371,7 @@ pub(crate) fn sysenter_exec(
         if !sandbox.filter_path(Capability::CAP_EXEC, path.abs()) {
             error!("ctx": "check_elf", "msg": "static linked ELF execution prevented",
                 "pid": pid.as_raw(), "path": path,
-                "tip": "configure `trace/deny_elf_static:0'",
+                "tip": "configure `trace/deny_exec_elf_static:0'",
                 "exe": format!("{exe}"));
         }
         return Err(Errno::EACCES);
@@ -522,7 +523,6 @@ pub(crate) fn sys_execveat(request: UNotifyEventRequest) -> ScmpNotifResp {
 // and it's vulnerable to TOCTOU. With ptrace on, this is mitigated
 // using the TOCTOU-mitigator, see the wait() function for context.
 // See: https://bugzilla.kernel.org/show_bug.cgi?id=218501
-#[allow(clippy::cognitive_complexity)]
 fn syscall_exec_handler(
     request: UNotifyEventRequest,
     syscall_name: &str,
@@ -586,7 +586,7 @@ fn syscall_exec_handler(
         //    if the file is not executable.
         // 2. We set MUST_PATH in FsFlags, path.dir is always Some.
         // This uses AT_EXECVE_CHECK on Linux>=6.14.
-        #[allow(clippy::disallowed_methods)]
+        #[expect(clippy::disallowed_methods)]
         if !is_executable(path.dir.as_ref().unwrap()) {
             return Err(Errno::EACCES);
         }
