@@ -751,13 +751,15 @@ fn handle_recvmmsg_internal(
         }
 
         // Write back mmsghdr for each result in the array.
+        let m32: mmsghdr32;
+        let m64: mmsghdr;
         let msg_header = if is32 {
-            let m32: mmsghdr32 = mmsghdr32::from(*mmsg_hdr);
+            m32 = mmsghdr32::from(*mmsg_hdr);
             let ptr = &raw const m32 as *const u8;
             // SAFETY: Writing directly from the raw memory of mmsghdr32.
             unsafe { std::slice::from_raw_parts(ptr, size_of::<mmsghdr32>()) }
         } else {
-            let m64: mmsghdr = (*mmsg_hdr).into();
+            m64 = (*mmsg_hdr).into();
             let ptr = &raw const m64 as *const u8;
             // SAFETY: Writing directly from the raw memory of mmsghdr.
             unsafe { std::slice::from_raw_parts(ptr, size_of::<mmsghdr>()) }
@@ -936,7 +938,9 @@ fn process_mmsghdr_ctl(
     if !hdr.msg_hdr.msg_control.is_null() && (hdr.msg_hdr.msg_control as u64) < *MMAP_MIN_ADDR {
         return Err(Errno::EFAULT);
     }
+    #[expect(clippy::cast_possible_truncation)]
     #[expect(clippy::disallowed_methods)]
+    #[expect(clippy::unnecessary_cast)]
     #[expect(clippy::useless_conversion)]
     if !hdr.msg_hdr.msg_control.is_null() && hdr.msg_hdr.msg_controllen > 0 {
         let mut ctl = Vec::new();
@@ -1108,6 +1112,7 @@ fn process_msghdr_ctl(
         let mut ctl = Vec::new();
         // SAFETY: Cap length at 1 mio.
         let mut len = hdr.msg_controllen.min(1_000_000);
+        #[expect(clippy::cast_possible_truncation)]
         if is32 {
             // SAFETY: CMSG_SPACE is always safe.
             len = unsafe { libc::CMSG_SPACE(len as u32) } as usize;
