@@ -23,7 +23,7 @@ impl Iterator for ZombieIterator {
                 Ok(PtraceEvent(..)) => {}
                 Ok(PtraceSyscall(..)) => {}
                 Ok(Exited(pid, status)) => {
-                    #[allow(clippy::cast_possible_truncation)]
+                    #[expect(clippy::cast_possible_truncation)]
                     return Some((pid.into(), ExitStatus::Exited(status as i8)));
                 }
                 Ok(Signaled(pid, sig, core)) => {
@@ -102,7 +102,7 @@ impl Iterator for ChildEventsIterator {
                 Ok(PtraceEvent(..)) => {}
                 Ok(PtraceSyscall(..)) => {}
                 Ok(Exited(pid, status)) => {
-                    #[allow(clippy::cast_possible_truncation)]
+                    #[expect(clippy::cast_possible_truncation)]
                     return Some(Death(pid.into(), ExitStatus::Exited(status as i8)));
                 }
                 Ok(Signaled(pid, sig, core)) => {
